@@ -20,12 +20,28 @@
 #
 #  If you're having any problems, don't hesitate to contact: andrew@andrewgee.org
 #
+import sys, os.path
+
+parent_dir = os.path.dirname(os.path.abspath(__file__))
+source_dir = os.path.join(parent_dir, "gpxviewer")
+sys.path.append(source_dir)
 
 import gtk.gdk
 from gpxviewer.ui import MainWindow
  
 gtk.gdk.threads_init()
 
-gui = MainWindow(ui_dir="ui/")
- 
-gtk.main()
+if len(sys.argv) > 2:
+	files = sys.argv[1:]
+elif len(sys.argv) > 1:
+	files = [sys.argv[1]]
+else:
+	files = []
+
+ui_dir = os.path.join(parent_dir, "ui/")
+
+gui = MainWindow(
+		ui_dir=ui_dir,
+		files=files
+).main()
+
